import { Server } from '../types';

const STORAGE_FILE = 'servers.json';

export const storage = {
  getServers: (): Server[] => {
    try {
      const data = localStorage.getItem(STORAGE_FILE);
      return data ? JSON.parse(data) : [];
    } catch (error) {
      console.error('Error reading servers:', error);
      return [];
    }
  },

  saveServers: (servers: Server[]): void => {
    try {
      localStorage.setItem(STORAGE_FILE, JSON.stringify(servers));
    } catch (error) {
      console.error('Error saving servers:', error);
    }
  },

  addServer: (server: Omit<Server, 'id' | 'created_at' | 'updated_at'>): Server => {
    const servers = storage.getServers();
    const newServer: Server = {
      ...server,
      id: crypto.randomUUID(),
      created_at: new Date().toISOString(),
      updated_at: new Date().toISOString()
    };
    
    servers.push(newServer);
    storage.saveServers(servers);
    return newServer;
  },

  deleteServer: (id: string): void => {
    const servers = storage.getServers();
    const filteredServers = servers.filter(server => server.id !== id);
    storage.saveServers(filteredServers);
  }
};